@@ -2,8 +2,6 @@ u"""
 Unit tests for ``django-envelope`` views.
 """
 
-import warnings
-
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
@@ -11,15 +9,12 @@ from django.test import TestCase
 from django.utils.translation import ugettext_lazy as _
 
 
-class BaseContactViewTestCase(TestCase):
+class ContactViewTestCase(TestCase):
     u"""
-    Base unit tests for contact form view.
-
-    These test cases are common to both class-based and function-based views.
-    Only the specific subclasses are imported in tests/__init__.py in order
-    not to duplicate tests.
+    Unit tests for contact form view.
     """
     url = reverse('envelope-contact')
+    customized_url = reverse('customized_class_contact')
 
     def setUp(self):
         self.honeypot = getattr(settings, 'HONEYPOT_FIELD_NAME', 'email2')
@@ -73,11 +68,23 @@ class BaseContactViewTestCase(TestCase):
         u"""
         If the honeypot field is not empty, keep the spammer off the page.
         """
-        response = self.client.post(self.url, {self.honeypot: 'some value'})
+        self.form_data.update({self.honeypot: 'some value'})
+        response = self.client.post(self.url, self.form_data)
         self.assertEqual(response.status_code, 400)
-        response = self.client.post(self.url, {self.honeypot: ''})
+        self.form_data.update({self.honeypot: ''})
+        response = self.client.post(self.url, self.form_data, follow=True)
         self.assertEqual(response.status_code, 200)
 
+    def test_form_invalid(self):
+        u"""
+        If the POST data is incorrect, the form is invalid.
+        """
+        self.form_data.update({'sender': ''})
+        response = self.client.post(self.url, self.form_data)
+        self.assertEqual(response.status_code, 200)
+        flash_error_message = _("There was en error in the contact form.")
+        self.assertContains(response, flash_error_message)
+
     def test_form_successful(self):
         u"""
         If the data is correct, a message is sent and the user is redirected.
@@ -90,14 +97,6 @@ class BaseContactViewTestCase(TestCase):
         flash_success_message = _("Thank you for your message.")
         self.assertContains(response, flash_success_message)
 
-
-class ClassContactViewTestCase(BaseContactViewTestCase):
-    u"""
-    Unit tests for class-based contact form view (the default one).
-    """
-    url = reverse('class_contact')
-    customized_url = reverse('customized_class_contact')
-
     def test_custom_template(self):
         u"""
         You can change the default template used to render the form.
@@ -111,39 +110,3 @@ class ClassContactViewTestCase(BaseContactViewTestCase):
         """
         response = self.client.post(self.customized_url, self.form_data)
         self.assertRedirects(response, self.customized_url)
-
-
-class FunctionContactViewTestCase(BaseContactViewTestCase):
-    u"""
-    Unit tests for old-style contact form view (function-based, deprecated).
-    """
-    url = reverse('func_contact')
-    customized_url = reverse('customized_func_contact')
-
-    def test_deprecation(self):
-        u"""
-        Function-based view is deprecated since 0.3.0.
-        """
-        with warnings.catch_warnings(record=True) as warns:
-            warnings.filterwarnings("always",
-                                    category=PendingDeprecationWarning)
-            self.client.get(self.url)
-            self.assertEqual(len(warns), 1)
-
-    def test_prefilled_form_no_full_name(self):
-        u"""
-        No new features in function-based view - this isn't implemented.
-        """
-        pass
-
-    def test_extra_context(self):
-        u"""
-        Custom context variables can be supplied to the view.
-        """
-        response = self.client.get(self.customized_url)
-        self.assertIn('foo', response.context)
-        self.assertEqual(response.context['foo'], 'bar')
-        # evaluate callables
-        self.assertIn('spam', response.context)
-        self.assertEqual(response.context['spam'], 'eggs')
-
