@@ -7,14 +7,12 @@ Views used to process the contact form.
 import logging
 
 from django.contrib import messages
-from django.shortcuts import redirect, render_to_response
-from django.template import RequestContext
-from django.utils.decorators import method_decorator
+from django.http import HttpResponseBadRequest
+from django.shortcuts import redirect
 from django.utils.translation import ugettext_lazy as _
 from django.views.generic import FormView
 
-from honeypot.decorators import check_honeypot
-
+from envelope import signals
 from envelope.forms import ContactForm
 
 
@@ -73,7 +71,6 @@ class ContactView(FormView):
         user = self.request.user
         if user.is_authenticated():
             # the user might not have a full name, depends on the registration
-            print user.get_full_name(), bool(user.get_full_name())
             if user.get_full_name():
                 sender = '%s (%s)' % (user.username, user.get_full_name())
             else:
@@ -88,6 +85,13 @@ class ContactView(FormView):
         u"""
         Sends the message and redirects the user somewhere.
         """
+        responses = signals.before_send.send(sender=self.__class__,
+                                             request=self.request,
+                                             form=form)
+        for (receiver, response) in responses:
+            if not response:
+                return HttpResponseBadRequest(_("Rejected by %s") %
+                                                receiver.__name__)
         form.save()
         messages.info(self.request,
                       _("Thank you for your message."),
@@ -98,76 +102,19 @@ class ContactView(FormView):
         u"""
         When the form has errors, display it again.
         """
+        messages.error(self.request,
+                       _("There was en error in the contact form."),
+                       fail_silently=True)
         return self.render_to_response(self.get_context_data(form=form))
 
-    @method_decorator(check_honeypot)
-    def dispatch(self, *args, **kwargs):
-        u"""
-        Overridden here to make decorators work.
-        """
-        return super(ContactView, self).dispatch(*args, **kwargs)
 
-
-@check_honeypot
-def contact(request,
-            form_class=ContactForm,
-            template_name='envelope/contact.html',
-            redirect_to=None,
-            extra_context=None):
+def filter_spam(sender, request, form, **kwargs):
     u"""
-    Contact form view (function-based).
-
-    If the user is authenticated, ``sender`` and ``email`` fields are
-    automatically filled with proper values.
-
-    **Optional arguments:**
-        * ``form_class``: Which form class to use for contact message handling.
-          The default (:class:`envelope.forms.ContactForm`) is often enough,
-          but you can subclass it if you want, or even replace with a totally
-          custom class. The only requirement is that your custom class has a
-          ``save()`` method which should send the message somewhere. Stick to
-          the default, or its subclasses.
-        * ``template_name``: Full name of the template which will display
-          the form. By default it is "envelope/contact.html".
-        * ``redirect_to``: URL of the page with some kind of a "thank you
-          for your feedback", displayed after the form is successfully
-          submitted. If left unset, the view redirects to itself.
-        * ``extra_context``: A dictionary of values to add to template context.
-
-    .. deprecated:: 0.3.0
+    Handle spam filtering.
     """
-    import warnings
-    warnings.warn("envelope.views.contact is deprecated, use the ContactView class instead", PendingDeprecationWarning)
-    if extra_context is None:
-        extra_context = {}
-    if request.method == 'POST':
-        form = form_class(request.POST)
-        if form.is_valid():
-            form.save()
-            messages.info(request,
-                          _("Thank you for your message."),
-                          fail_silently=True)
-            if redirect_to is None:
-                redirect_to = request.get_full_path()
-            return redirect(redirect_to)
-        else:
-            messages.error(request,
-                           _("There was en error in the contact form."),
-                           fail_silently=True)
-    else:
-        if request.user.is_authenticated():
-            initial = {
-                'sender': '%s (%s)' % (request.user.username,
-                                       request.user.get_full_name()),
-                'email': request.user.email,
-            }
-            form = form_class(initial=initial)
-        else:
-            form = form_class()
-    dictionary = {'form': form}
-    for key, value in extra_context.items():
-        dictionary[key] = callable(value) and value() or value
-    return render_to_response(template_name,
-                              dictionary,
-                              context_instance=RequestContext(request))
+    from envelope.spam_filters import check_honeypot
+    return check_honeypot(request, form)
 
+
+signals.before_send.connect(filter_spam, sender=ContactView,
+                            dispatch_uid='envelope.views.filter_spam')
